 /// \file
 /// \ingroup tutorial_tmva
 /// \notebook -nodraw
 /// This example explains how to use the cross-validation feature of TMVA. It is
 /// validated the Fisher algorithm with a 5-fold cross-validation.
 /// - Project   : TMVA - a Root-integrated toolkit for multivariate data analysis
 /// - Package   : TMVA
 /// - Exectuable: TMVACrossValidation
 ///
 /// \macro_output
 /// \macro_code
 /// \author Stefan Wunsch
 
 #include "TFile.h"
 #include "TTree.h"
 #include "TString.h"
 #include "TSystem.h"
 
 #include "TMVA/DataLoader.h"
 #include "TMVA/CrossValidation.h"
 #include "TMVA/Tools.h"
 
 void TMVACrossValidation()
 {
    // This loads the library
    TMVA::Tools::Instance();
 
    // Load data
    TFile *input(0);
    TString fname = "ntuple.root";
    if (!gSystem->AccessPathName( fname )) {
       input = TFile::Open( fname ); // check if file in local directory exists
    }
    else {
       
       std::cout << "ERROR: could not open data file" << std::endl;
       exit(1);
    }
 
    TFile* fout = new TFile("TMVA.root","RECREATE");


    TTree* ntuple = (TTree*)input->Get("ntuple");

 
    // Setup dataloader
    TMVA::DataLoader* dataloader = new TMVA::DataLoader("dataset");
 
    dataloader->AddSignalTree(ntuple,1.0);
    dataloader->AddBackgroundTree(ntuple,1.0);
 
    dataloader->AddVariable("x");
    dataloader->AddVariable("y");


 
    // cuts defining the signal and background sample
    TCut sigCut = TCut("signal > 0.5");
    TCut bgCut =  TCut("signal <= 0.5");
 
    dataloader->PrepareTrainingAndTestTree(sigCut, bgCut, "SplitMode=Random:NormMode=NumEvents:!V:nTrain_Signal=2000:nTrain_Background=2000:nTest_Signal=2000:nTest_Background=2000");
 
    // Setup cross-validation with Fisher method
    TMVA::CrossValidation cv("TMVACrossValidation",dataloader,fout,
                                        "!Silent:ModelPersistence:AnalysisType=Classification:NumFolds=5:!V");

    //cv.BookMethod(TMVA::Types::kFisher, "Fisher", "!H:!V:Fisher");
    cv.BookMethod(TMVA::Types::kBDT, "BDT", "!H:!V:NTrees=100:MaxDepth=4:BoostType=AdaBoost:AdaBoostBeta=0.5:SeparationType=GiniIndex:nCuts=20");

    // Run cross-validation and print results
    cv.Evaluate();
    auto results = cv.GetResults();
    for (auto r : results){
       r.Print();
       }
    
 }
 
 int main()
 {
    TMVACrossValidation();



 }
